@@ -45,7 +45,7 @@ static PyObject* firebaseRemoteConfig_GetString(firebaseRemoteConfig_obj* self,
 	char* key = nullptr;
 	if (!PyArg_ParseTuple(args, "s", &key)) return NULL;
 
-	std::string result = FirebaseRemoteConfig::Instance()->getString(key);
+	std::string result = FirebaseRemoteConfig::Instance()->GetString(key);
 	PyObject* obj = PyBytes_FromString(result.c_str());
 
 	return obj;
@@ -75,6 +75,14 @@ static PyObject* firebaseRemoteConfig_GetBoolean(firebaseRemoteConfig_obj* self,
 	return PyLong_FromLong(FirebaseRemoteConfig::Instance()->GetBoolean(key));
 }
 
+static PyObject* firebaseRemoteConfig_FetchAll(firebaseRemoteConfig_obj* self)
+{
+	FirebaseRemoteConfig::Instance()->FetchAll();
+
+	Py_INCREF(Py_None);
+	return Py_None;
+}
+
 PyMethodDef firebaseRemoteConfig_methods[] = {
 	{ "init", (PyCFunction)firebaseRemoteConfig_Init, METH_NOARGS, firebaseRemoteConfigInit_doc },
 	{ "release", (PyCFunction)firebaseRemoteConfig_Release, METH_NOARGS, firebaseRemoteConfigRelease_doc },
@@ -82,6 +90,7 @@ PyMethodDef firebaseRemoteConfig_methods[] = {
 	{ "getLong", (PyCFunction)firebaseRemoteConfig_GetLong, METH_VARARGS, firebaseRemoteConfigGetLong_doc },
 	{ "getFloat", (PyCFunction)firebaseRemoteConfig_GetFloat, METH_VARARGS, firebaseRemoteConfigGetFloat_doc },
 	{ "getBoolean", (PyCFunction)firebaseRemoteConfig_GetBoolean, METH_VARARGS, firebaseRemoteConfigGetBoolean_doc },
+	{ "fetch", (PyCFunction)firebaseRemoteConfig_FetchAll, METH_NOARGS, firebaseRemoteConfigFetch_doc },
 	{ NULL,	NULL }
 };
 
