@@ -240,4 +240,10 @@ PyDoc_STRVAR(firebaseRemoteConfigGetBoolean_doc,
 	"    key : string\n"\
 	"Returns\n"\
 	"-------\n"\
-	"    result : boolean");
\ No newline at end of file
+	"    result : boolean");
+
+//firebase remote config fetch
+PyDoc_STRVAR(firebaseRemoteConfigFetch_doc,
+	"fetch the new data\n"\
+	"\n"\
+	"firebaseRemoteConfig.fetch()");
\ No newline at end of file
