@@ -246,6 +246,21 @@ void FirebaseImpl::RemoteConfigRelease()
 	firebase::remote_config::Terminate();
 }
 
+void FirebaseImpl::RemoteConfigFetchAll()
+{
+	auto future_result = firebase::remote_config::Fetch(0);
+	while (future_result.status() == firebase::kFutureStatusPending) {
+		if (ProcessEvents(1000)) {
+			break;
+		}
+	}
+
+	if (future_result.status() == firebase::kFutureStatusComplete) {
+		bool activate_result = firebase::remote_config::ActivateFetched();
+		LOG("ActivateFetched %s", activate_result ? "succeeded" : "failed");
+	}
+}
+
 void FirebaseImpl::WaitForFutureCompletion(firebase::FutureBase future, firebase::FutureStatus toCheck, int msec, double timeout)
 {
     double time = GetTime();
